import { getTranslations } from "next-intl/server";

import ProductCarousel from "@/components/shared/product-carousel";
import BlurFade from "@/components/ui/blur-fade";
import { Locale } from "@/i18n/routing";

async function ProductsForService({
	lang,
	products,
}: {
	lang: Locale;
	products: any;
}) {
	const t = await getTranslations("Services");

	const services = products?.map((product: any) => ({
		id: product.id,
		ProductName: lang === "ar" ? product.name : product.name_en,
		description: lang === "ar" ? product.description : product.description_en,
		oldPrice: product.price,
		newPrice: product.final_price,
		image: product.images?.find((image: any) => image.is_main === 1)?.name,
	}));

	return (
		<section className="my-7 flex flex-col items-center gap-4 md:my-24">
			<ProductCarousel
				items={services}
				lang={lang}
				title={t("ProductsForService")}
				customSubTitle={
					<BlurFade
						blur="6px"
						direction="up"
						inView
						offset={10}
						duration={0.5}
						className="mb-12 text-[40px] leading-[48px] text-[#202020]"
					>
						{t("ProductsService")}
					</BlurFade>
				}
			/>
		</section>
	);
}

export default ProductsForService;
